@@ -259,6 +259,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk
@@ -287,6 +289,10 @@ class RemoteOutputs(
         :param stack: The remote CDK stack to get the outputs from.
         :param always_update: Indicate whether always update the custom resource to get the new stack output. Default: true
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RemoteOutputs.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = RemoteOutputsProps(stack=stack, always_update=always_update)
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -297,9 +303,12 @@ class RemoteOutputs(
 
         :param key: output key.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RemoteOutputs.get)
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
         return typing.cast(builtins.str, jsii.invoke(self, "get", [key]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="outputs")
     def outputs(self) -> aws_cdk.CustomResource:
         '''The outputs from the remote stack.'''
@@ -323,6 +332,10 @@ class RemoteOutputsProps:
         :param stack: The remote CDK stack to get the outputs from.
         :param always_update: Indicate whether always update the custom resource to get the new stack output. Default: true
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RemoteOutputsProps.__init__)
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
+            check_type(argname="argument always_update", value=always_update, expected_type=type_hints["always_update"])
         self._values: typing.Dict[str, typing.Any] = {
             "stack": stack,
         }
@@ -382,6 +395,10 @@ class RemoteParameters(
         :param always_update: Indicate whether always update the custom resource to get the new stack output. Default: true
         :param role: The assumed role used to get remote parameters.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RemoteParameters.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = RemoteParametersProps(
             path=path, region=region, always_update=always_update, role=role
         )
@@ -394,9 +411,12 @@ class RemoteParameters(
 
         :param key: output key.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RemoteParameters.get)
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
         return typing.cast(builtins.str, jsii.invoke(self, "get", [key]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="parameters")
     def parameters(self) -> aws_cdk.CustomResource:
         '''The parameters in the SSM parameter store for the remote stack.'''
@@ -429,6 +449,12 @@ class RemoteParametersProps:
         :param always_update: Indicate whether always update the custom resource to get the new stack output. Default: true
         :param role: The assumed role used to get remote parameters.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RemoteParametersProps.__init__)
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
+            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
+            check_type(argname="argument always_update", value=always_update, expected_type=type_hints["always_update"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
         self._values: typing.Dict[str, typing.Any] = {
             "path": path,
             "region": region,
